<p align="center">
  <a href="https://github.com/realkarych/rxconf">
  <img src="https://github.com/user-attachments/assets/d9e426cf-5ad6-4a1d-8c5d-ac9dbdd1e63a" alt="RxConf"></a>
</p>

<p align="center">
    <em>RxConf library, easy to use, powerful and flexible for [realtime] configuration management in Python</em>
</p>

<p align="center">
  <img src="https://realkarych.github.io/rxconf/coverage.svg" alt="Coverage">
  <img src="https://github.com/realkarych/rxconf/actions/workflows/run_tests.yml/badge.svg" alt="Tests status">
  <img src="https://img.shields.io/pypi/v/rxconf" alt="PyPI version">
  <img src="https://img.shields.io/pypi/pyversions/rxconf?color=dark-green" alt="Supported Python versions">
  <img src="https://img.shields.io/badge/Supported%20OS-Windows%2C%20macOS%2C%20Linux-default" alt="Supported OS">
  <img src="https://static.pepy.tech/badge/rxconf/month" alt="Downloads per month">
</p>

---

**Documentation:** <https://realkarych.github.io/rxconf/>

**Source code:** <https://github.com/realkarych/rxconf/>

**TL;DR:** `pip install rxconf`

---

<h1 align="center">
Currently in develop...
</h1>

- [x] Implement RxConf DAO
  - [x] Implement base DAO
  - [x] Implement env-vars & dotenv-files DAO
  - [x] Implement `yaml` DAO
  - [x] Implement `toml` DAO
  - [x] Implement `ini` DAO
  - [x] Implement `json` DAO
- [x] Implement concurrent IO mode for DAOs
- [ ] Implement observers
  - [ ] Add base observer
  - [ ] Add decorator that provides DI mechanism to inject actual config state
